@@ -145,9 +145,11 @@ wnba_cumestatsplayer <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no cumulative player stats data available for {player_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no cumulative player stats data available for {player_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -230,9 +232,11 @@ wnba_cumestatsplayergames <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no cumulative player game stats data available for {player_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no cumulative player game stats data available for {player_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -391,9 +395,11 @@ wnba_cumestatsteam <- function(
       df_list <- wnba_stats_map_result_sets(resp)
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no cumulative team stats data available for {team_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no cumulative team stats data available for {team_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -478,9 +484,11 @@ wnba_cumestatsteamgames <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no cumulative team game stats data available for {team_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no cumulative team game stats data available for {team_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
