@@ -65,9 +65,11 @@ wnba_franchiseleaders <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no franchise leaders data available for {team_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no franchise leaders data available for {team_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -180,9 +182,11 @@ wnba_franchiseleaderswrank <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no franchise players data available for {team_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no franchise players data available for {team_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -277,9 +281,11 @@ wnba_franchiseplayers <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no franchise players data available for {team_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no franchise players data available for {team_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -372,12 +378,14 @@ wnba_franchisehistory <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no franchise history data available for {team_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no franchise history data available for {team_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
   )
   return(df_list)
-}
\ No newline at end of file
+}
