@@ -150,9 +150,11 @@ wnba_leaguehustlestatsplayer <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league hustle player stats data available for {season}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league hustle player stats data available for {season}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -357,9 +359,11 @@ wnba_leaguehustlestatsplayerleaders <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league hustle stats player leaders data available for {season}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league hustle stats player leaders data available for {season}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -510,9 +514,11 @@ wnba_leaguehustlestatsteam <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league hustle team stats data available for {season}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league hustle team stats data available for {season}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -715,12 +721,14 @@ wnba_leaguehustlestatsteamleaders <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league hustle team stats leaders data available for {season}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league hustle team stats leaders data available for {season}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
   )
   return(df_list)
-}
\ No newline at end of file
+}
