@@ -101,9 +101,11 @@ wnba_leaguegamelog <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league game log data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league game log data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -260,9 +262,11 @@ wnba_leaguestandingsv3 <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league standings v3 data available for {season}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league standings v3 data available for {season}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -609,9 +613,11 @@ wnba_leaguegamefinder <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league game finder data available for the given parameters!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league game finder data available for the given parameters!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -788,7 +794,7 @@ wnba_leaguegamefinder <- function(
 #        
 #      },
 #      error = function(e) {
-#        message(glue::glue("{Sys.time()}: Invalid arguments or no playoff picture data available for {season}!"))
+#        cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no playoff picture data available for {season}!")
 #      },
 #      warning = function(w) {
 #      },
