@@ -166,9 +166,11 @@ wnba_leaguedashplayerbiostats <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league dashboard player bio stats data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league dashboard player bio stats data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -409,9 +411,11 @@ wnba_leaguedashplayerclutch <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league dashboard player clutch stats data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league dashboard player clutch stats data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -641,9 +645,11 @@ wnba_leaguedashplayerstats <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league dashboard player stats data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league dashboard player stats data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -854,9 +860,11 @@ wnba_leaguedashplayershotlocations <- function(
       names(df_list) <- resp$resultSets$name
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league dashboard player shot locations data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league dashboard player shot locations data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1065,9 +1073,11 @@ wnba_leaguedashteamclutch <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league dashboard team clutch data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league dashboard team clutch data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1261,9 +1271,11 @@ wnba_leaguedashteamstats <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league dashboard team stats data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league dashboard team stats data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1448,9 +1460,11 @@ wnba_leaguedashteamshotlocations <- function(
       names(df_list) <- resp$resultSets$name
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no league dashboard team shot location data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no league dashboard team shot location data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
