@@ -107,9 +107,11 @@ wnba_playerindex <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player index data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player index data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -150,9 +152,11 @@ wnba_playerheadshot <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player headshot for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player headshot for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -222,9 +226,11 @@ wnba_playerawards <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player awards data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player awards data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -317,9 +323,11 @@ wnba_playercareerbycollege <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or player careers by college data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or player careers by college data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -500,9 +508,11 @@ wnba_playercareerbycollegerollup <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or player careers by college rollup data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or player careers by college rollup data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -825,9 +835,11 @@ wnba_playercareerstats <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or player career stats data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or player career stats data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -916,9 +928,11 @@ wnba_infographicfanduelplayer <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no FanDuel player infographic data for {game_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no FanDuel player infographic data for {game_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1185,9 +1199,11 @@ wnba_playerfantasyprofile <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player fantasy profile data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player fantasy profile data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1292,9 +1308,11 @@ wnba_playerfantasyprofilebargraph <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player fantasy profile bar graph data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player fantasy profile bar graph data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1400,9 +1418,11 @@ wnba_playerestimatedmetrics <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player estimated metrics data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player estimated metrics data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1502,9 +1522,11 @@ wnba_playergamelog <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player game log data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player game log data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -1687,9 +1709,11 @@ wnba_playergamelogs <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player game logs data for {player_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player game logs data for {player_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -2022,9 +2046,11 @@ wnba_playergamestreakfinder <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player streak finder data available for the parameters selected!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player streak finder data available for the parameters selected!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -2107,9 +2133,11 @@ wnba_playernextngames <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player next n games data available for {player_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player next n games data available for {player_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -2543,9 +2571,11 @@ wnba_playerprofilev2 <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no player profile v2 data available for {player_id}!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no player profile v2 data available for {player_id}!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -2860,9 +2890,11 @@ wnba_playervsplayer <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or player vs player data unavailable for the parameters selected!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or player vs player data unavailable for the parameters selected!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -3043,9 +3075,11 @@ wnba_playercompare <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or player comparison data unavailable for the parameters selected!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or player comparison data unavailable for the parameters selected!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
