@@ -68,9 +68,11 @@ wnba_commonallplayers <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or common all players data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or common all players data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -183,9 +185,11 @@ wnba_commonplayerinfo <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or common player info data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or common player info data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -250,9 +254,11 @@ wnba_commonplayoffseries <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or common playoff series data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or common playoff series data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -345,9 +351,11 @@ wnba_commonteamroster <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or common team roster data for {season} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or common team roster data for {season} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
