@@ -175,9 +175,11 @@ wnba_videodetailsasset <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no video detail assets data available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no video detail assets data available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -361,9 +363,11 @@ wnba_videodetails <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no video details data available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no video details data available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -423,9 +427,11 @@ wnba_videoevents <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no video events data for {game_id} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no video events data for {game_id} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
@@ -498,9 +504,11 @@ wnba_videostatus <- function(
       
     },
     error = function(e) {
-      message(glue::glue("{Sys.time()}: Invalid arguments or no video status data for {game_date} available!"))
+      cli::cli_alert_danger("{Sys.time()}: Invalid arguments or no video status data for {game_date} available!")
+      cli::cli_alert_danger("Error:\n{e}")
     },
     warning = function(w) {
+      cli::cli_alert_warning("{Sys.time()}: Warning:\n{w}")
     },
     finally = {
     }
