@@ -83,16 +83,17 @@ test_that("ESPN - WBB Play-by-Play", {
     "assists",
     "blocks",
     "defensive_rebounds",
+    "fast_break_points",
     "field_goal_pct",
     "field_goals_made",
     "field_goals_attempted",
-    "flagrant_fouls",
     "fouls",
     "free_throw_pct",
     "free_throws_made",
     "free_throws_attempted",
     "largest_lead",
     "offensive_rebounds",
+    "points_in_paint",
     "steals",
     "team_turnovers",
     "technical_fouls",
@@ -102,6 +103,7 @@ test_that("ESPN - WBB Play-by-Play", {
     "total_rebounds",
     "total_technical_fouls",
     "total_turnovers",
+    "turnover_points",
     "turnovers",
     "opponent_team_id",
     "opponent_team_uid",
