@@ -19,10 +19,15 @@ test_that("ESPN - WBB Player Stats", {
     "birth_place_city",
     "birth_place_state",
     "birth_place_country",
+    "birth_country_alternate_id",
+    "birth_country_abbreviation",
     "slug",
     "headshot_href",
     "headshot_alt",
     "jersey",
+    "flag_href",
+    "flag_alt",
+    "flag_x_country_flag",
     "position_id",
     "position_name",
     "position_display_name",
@@ -88,6 +93,7 @@ test_that("ESPN - WBB Player Stats", {
     "offensive_three_point_field_goals_made",
     "offensive_total_turnovers",
     "offensive_points_in_paint",
+    "offensive_second_chance_points",
     "offensive_fast_break_points",
     "offensive_avg_field_goals_made",
     "offensive_avg_field_goals_attempted",
@@ -113,6 +119,7 @@ test_that("ESPN - WBB Player Stats", {
     "offensive_two_point_field_goal_pct",
     "offensive_shooting_efficiency",
     "offensive_scoring_efficiency",
+    "team_x_ref_2",
     "team_id",
     "team_guid",
     "team_uid",
@@ -127,7 +134,7 @@ test_that("ESPN - WBB Player Stats", {
     "team_color",
     "team_alternate_color",
     "team_is_active",
-    "team_is_all_star",
+    "is_all_star",
     "logo_href",
     "logo_dark_href"
   )
