@@ -6,6 +6,6 @@ test_that("NCAA - WBB NET Rankings", {
   skip_on_cran()
   x <- ncaa_wbb_NET_rankings()
   
-  expect_equal(colnames(x), cols)
+  expect_in(colnames(x), cols)
   expect_s3_class(x, "data.frame")
 })
