@@ -25,6 +25,8 @@ test_that("WNBA Schedule", {
     "week_name",
     "if_necessary",
     "series_game_number",
+    "game_label",
+    "game_sub_label",
     "series_text",
     "arena_name",
     "arena_state",
@@ -51,7 +53,9 @@ test_that("WNBA Schedule", {
     "away_team_score",
     "away_team_seed",
     "season",
-    "league_id"
+    "league_id",
+    "season_type_id",
+    "season_type_description"
   )
   
   expect_equal(sort(colnames(x)), sort(cols_x1))
